@@ -11,31 +11,33 @@
 //!
 //! # Including Strum in Your Project
 //!
-//! Import strum and strum_macros into your project by adding the following lines to your
-//! Cargo.toml. Strum_macros contains the macros needed to derive all the traits in Strum.
+//! Import strum and `strum_macros` into your project by adding the following lines to your
+//! Cargo.toml. `strum_macros` contains the macros needed to derive all the traits in Strum.
 //!
 //! ```toml
 //! [dependencies]
-//! strum = "0.20"
-//! strum_macros = "0.20"
+//! strum = "0.24"
+//! strum_macros = "0.24"
 //!
 //! # You can also access strum_macros exports directly through strum using the "derive" feature
-//! strum = { version = "0.20", features = ["derive"] }
+//! strum = { version = "0.24", features = ["derive"] }
 //! ```
 //!
 
+#![cfg_attr(not(feature = "std"), no_std)]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 
 // only for documentation purposes
 pub mod additional_attributes;
 
-/// The ParseError enum is a collection of all the possible reasons
+/// The `ParseError` enum is a collection of all the possible reasons
 /// an enum can fail to parse from a string.
 #[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
 pub enum ParseError {
     VariantNotFound,
 }
 
+#[cfg(feature = "std")]
 impl std::fmt::Display for ParseError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> Result<(), std::fmt::Error> {
         // We could use our macro here, but this way we don't take a dependency on the
@@ -46,6 +48,7 @@ impl std::fmt::Display for ParseError {
     }
 }
 
+#[cfg(feature = "std")]
 impl std::error::Error for ParseError {
     fn description(&self) -> &str {
         match self {
@@ -96,7 +99,7 @@ pub trait IntoEnumIterator: Sized {
 
 /// Associates additional pieces of information with an Enum. This can be
 /// autoimplemented by deriving `EnumMessage` and annotating your variants with
-/// `#[strum(message="...")].
+/// `#[strum(message="...")]`.
 ///
 /// # Example
 ///
@@ -110,6 +113,7 @@ pub trait IntoEnumIterator: Sized {
 ///     #[strum(message="I have a dog")]
 ///     #[strum(detailed_message="My dog's name is Spots")]
 ///     Dog,
+///     /// I am documented.
 ///     #[strum(message="I don't have a cat")]
 ///     Cat,
 /// }
@@ -118,12 +122,15 @@ pub trait IntoEnumIterator: Sized {
 /// assert_eq!("I have a dog", my_pet.get_message().unwrap());
 /// ```
 pub trait EnumMessage {
-    fn get_message(&self) -> Option<&str>;
-    fn get_detailed_message(&self) -> Option<&str>;
-    fn get_serializations(&self) -> &[&str];
+    fn get_message(&self) -> Option<&'static str>;
+    fn get_detailed_message(&self) -> Option<&'static str>;
+
+    /// Get the doc comment associated with a variant if it exists.
+    fn get_documentation(&self) -> Option<&'static str>;
+    fn get_serializations(&self) -> &'static [&'static str];
 }
 
-/// EnumProperty is a trait that makes it possible to store additional information
+/// `EnumProperty` is a trait that makes it possible to store additional information
 /// with enum variants. This trait is designed to be used with the macro of the same
 /// name in the `strum_macros` crate. Currently, the only string literals are supported
 /// in attributes, the other methods will be implemented as additional attribute types
@@ -163,7 +170,10 @@ pub trait EnumProperty {
 
 /// A cheap reference-to-reference conversion. Used to convert a value to a
 /// reference value with `'static` lifetime within generic code.
-/// #[deprecated(since="0.13.0", note="please use `#[derive(IntoStaticStr)]` instead")]
+#[deprecated(
+    since = "0.22.0",
+    note = "please use `#[derive(IntoStaticStr)]` instead"
+)]
 pub trait AsStaticRef<T>
 where
     T: ?Sized,
@@ -212,6 +222,7 @@ DocumentMacroRexports! {
     EnumProperty,
     EnumString,
     EnumVariantNames,
+    FromRepr,
     IntoStaticStr,
     ToString
 }
